@@ -1,22 +1,23 @@
-from __future__ import unicode_literals
-
 from io import BytesIO
 from textwrap import dedent
 import json
 
-import mock
+from unittest import mock
 
 from diff_cover.diff_reporter import BaseDiffReporter
 from diff_cover.report_generator import (
-    BaseReportGenerator, HtmlReportGenerator,
-    StringReportGenerator, TemplateReportGenerator,
-    JsonReportGenerator
-)
-from diff_cover.tests.helpers import (
-    load_fixture, assert_long_str_equal
+    BaseReportGenerator,
+    HtmlReportGenerator,
+    StringReportGenerator,
+    TemplateReportGenerator,
+    JsonReportGenerator,
 )
+from diff_cover.tests.helpers import load_fixture, assert_long_str_equal
 import unittest
-from diff_cover.violationsreporters.violations_reporter import BaseViolationReporter, Violation
+from diff_cover.violationsreporters.violations_reporter import (
+    BaseViolationReporter,
+    Violation,
+)
 
 
 class SimpleReportGenerator(BaseReportGenerator):
@@ -25,7 +26,7 @@ class SimpleReportGenerator(BaseReportGenerator):
     """
 
     def __init__(self, cover, diff):
-        super(SimpleReportGenerator, self).__init__(cover, diff)
+        super().__init__(cover, diff)
 
     def generate_report(self, output_file):
         pass
@@ -37,7 +38,7 @@ class BaseReportGeneratorTest(unittest.TestCase):
     """
 
     # Test data, returned by default from the mocks
-    SRC_PATHS = {'file1.py', 'subdir/file2.py'}
+    SRC_PATHS = {"file1.py", "subdir/file2.py"}
     LINES = [2, 3, 4, 5, 10, 11, 12, 13, 14, 15]
     VIOLATIONS = [Violation(n, None) for n in (10, 11, 20)]
     MEASURED = [1, 2, 3, 4, 7, 10, 11, 15, 20, 30]
@@ -50,7 +51,7 @@ class BaseReportGeneratorTest(unittest.TestCase):
 
     # Snippet returned by the mock
     SNIPPET = "<div>Snippet with \u1235 \u8292 unicode</div>"
-    SNIPPET_STYLE = '.css { color:red }'
+    SNIPPET_STYLE = ".css { color:red }"
 
     def setUp(self):
 
@@ -62,15 +63,13 @@ class BaseReportGeneratorTest(unittest.TestCase):
 
         # Patch snippet loading to always return the same string
         self._load_snippets_html = mock.patch(
-            'diff_cover.snippets.Snippet.load_snippets_html'
+            "diff_cover.snippets.Snippet.load_snippets_html"
         ).start()
 
         self.set_num_snippets(0)
 
         # Patch snippet style
-        style_defs = mock.patch(
-            'diff_cover.snippets.Snippet.style_defs'
-        ).start()
+        style_defs = mock.patch("diff_cover.snippets.Snippet.style_defs").start()
 
         style_defs.return_value = self.SNIPPET_STYLE
 
@@ -125,8 +124,7 @@ class BaseReportGeneratorTest(unittest.TestCase):
         Patch the depdenency `Snippet.load_snippets_html()`
         to return `num_snippets` of the fake snippet HTML.
         """
-        self._load_snippets_html.return_value = \
-            num_snippets * [self.SNIPPET]
+        self._load_snippets_html.return_value = num_snippets * [self.SNIPPET]
 
     def use_default_values(self):
         """
@@ -159,7 +157,7 @@ class BaseReportGeneratorTest(unittest.TestCase):
         output_str = output.getvalue()
         output.close()
 
-        return output_str.decode('utf-8')
+        return output_str.decode("utf-8")
 
     def assert_report(self, expected):
         output_report_string = self.get_report()
@@ -171,19 +169,17 @@ class SimpleReportGeneratorTest(BaseReportGeneratorTest):
     REPORT_GENERATOR_CLASS = SimpleReportGenerator
 
     def setUp(self):
-        super(SimpleReportGeneratorTest, self).setUp()
+        super().setUp()
         self.use_default_values()
 
     def test_src_paths(self):
         self.assertEqual(self.report.src_paths(), self.SRC_PATHS)
 
     def test_coverage_name(self):
-        self.assertEqual(self.report.coverage_report_name(),
-                         self.XML_REPORT_NAME)
+        self.assertEqual(self.report.coverage_report_name(), self.XML_REPORT_NAME)
 
     def test_diff_name(self):
-        self.assertEqual(self.report.diff_report_name(),
-                         self.DIFF_REPORT_NAME)
+        self.assertEqual(self.report.diff_report_name(), self.DIFF_REPORT_NAME)
 
     def test_percent_covered(self):
 
@@ -194,9 +190,7 @@ class SimpleReportGeneratorTest(BaseReportGeneratorTest):
         # There are 6 lines that are both in the diff and measured,
         # and 4 of those are covered.
         for src_path in self.SRC_PATHS:
-            self.assertAlmostEqual(
-                self.report.percent_covered(src_path),
-                4.0 / 6 * 100)
+            self.assertAlmostEqual(self.report.percent_covered(src_path), 4.0 / 6 * 100)
 
     def test_violation_lines(self):
 
@@ -207,20 +201,20 @@ class SimpleReportGeneratorTest(BaseReportGeneratorTest):
 
     def test_src_with_no_info(self):
 
-        self.assertNotIn('unknown.py', self.report.src_paths())
-        self.assertIs(self.report.percent_covered('unknown.py'), None)
-        self.assertEqual(self.report.violation_lines('unknown.py'), [])
+        self.assertNotIn("unknown.py", self.report.src_paths())
+        self.assertIs(self.report.percent_covered("unknown.py"), None)
+        self.assertEqual(self.report.violation_lines("unknown.py"), [])
 
     def test_src_paths_not_measured(self):
 
         # Configure one of the source files to have no coverage info
-        self.set_measured('file1.py', [])
-        self.set_violations('file1.py', [])
+        self.set_measured("file1.py", [])
+        self.set_violations("file1.py", [])
 
         # Expect that we treat the file like it doesn't exist
-        self.assertNotIn('file1.py', self.report.src_paths())
-        self.assertIs(self.report.percent_covered('file1.py'), None)
-        self.assertEqual(self.report.violation_lines('file1.py'), [])
+        self.assertNotIn("file1.py", self.report.src_paths())
+        self.assertIs(self.report.percent_covered("file1.py"), None)
+        self.assertEqual(self.report.violation_lines("file1.py"), [])
 
     def test_total_num_lines(self):
 
@@ -249,18 +243,21 @@ class TemplateReportGeneratorTest(BaseReportGeneratorTest):
 
     def _test_input_expected_output(self, input_with_expected_output):
         for test_input, expected_output in input_with_expected_output:
-            self.assertEqual(expected_output,
-                             TemplateReportGenerator.combine_adjacent_lines(test_input))
+            self.assertEqual(
+                expected_output,
+                TemplateReportGenerator.combine_adjacent_lines(test_input),
+            )
 
     def test_combine_adjacent_lines_no_adjacent(self):
-        in_out = [([1, 3], ["1", "3"]),
-                  ([1, 5, 7, 10], ["1", "5", "7", "10"])]
+        in_out = [([1, 3], ["1", "3"]), ([1, 5, 7, 10], ["1", "5", "7", "10"])]
         self._test_input_expected_output(in_out)
 
     def test_combine_adjacent_lines(self):
-        in_out = [([1, 2, 3, 4, 5, 8, 10, 12, 13, 14, 15], ["1-5", "8", "10", "12-15"]),
-                  ([1, 4, 5, 6, 10], ["1", "4-6", "10"]),
-                  ([402, 403], ["402-403"])]
+        in_out = [
+            ([1, 2, 3, 4, 5, 8, 10, 12, 13, 14, 15], ["1-5", "8", "10", "12-15"]),
+            ([1, 4, 5, 6, 10], ["1", "4-6", "10"]),
+            ([402, 403], ["402-403"]),
+        ]
         self._test_input_expected_output(in_out)
 
     def test_empty_list(self):
@@ -276,10 +273,7 @@ class JsonReportGeneratorTest(BaseReportGeneratorTest):
 
     def assert_report(self, expected):
         output_report_string = self.get_report()
-        self.assertDictEqual(
-            json.loads(expected),
-            json.loads(output_report_string)
-        )
+        self.assertDictEqual(json.loads(expected), json.loads(output_report_string))
 
     def test_generate_report(self):
 
@@ -287,50 +281,54 @@ class JsonReportGeneratorTest(BaseReportGeneratorTest):
         self.use_default_values()
 
         # Verify that we got the expected string
-        expected = json.dumps({
-            'report_name': ['reports/coverage.xml'],
-            'diff_name': 'master',
-            'src_stats': {
-                'file1.py': {
-                    'percent_covered': 66.66666666666667,
-                    'violation_lines': [10, 11],
-                    'violations': [[10, None], [11, None]]
+        expected = json.dumps(
+            {
+                "report_name": ["reports/coverage.xml"],
+                "diff_name": "master",
+                "src_stats": {
+                    "file1.py": {
+                        "percent_covered": 66.66666666666667,
+                        "violation_lines": [10, 11],
+                        "violations": [[10, None], [11, None]],
+                    },
+                    "subdir/file2.py": {
+                        "percent_covered": 66.66666666666667,
+                        "violation_lines": [10, 11],
+                        "violations": [[10, None], [11, None]],
+                    },
                 },
-                'subdir/file2.py': {
-                    'percent_covered': 66.66666666666667,
-                    'violation_lines': [10, 11],
-                    'violations': [[10, None], [11, None]]
-                }
-            },
-            'total_num_lines': 12,
-            'total_num_violations': 4,
-            'total_percent_covered': 66
-        })
+                "total_num_lines": 12,
+                "total_num_violations": 4,
+                "total_percent_covered": 66,
+            }
+        )
 
         self.assert_report(expected)
 
     def test_hundred_percent(self):
 
         # Have the dependencies return an empty report
-        self.set_src_paths_changed(['file.py'])
-        self.set_lines_changed('file.py', [line for line in range(0, 100)])
-        self.set_violations('file.py', [])
-        self.set_measured('file.py', [2])
+        self.set_src_paths_changed(["file.py"])
+        self.set_lines_changed("file.py", [line for line in range(0, 100)])
+        self.set_violations("file.py", [])
+        self.set_measured("file.py", [2])
 
-        expected = json.dumps({
-            'report_name': ['reports/coverage.xml'],
-            'diff_name': 'master',
-            'src_stats': {
-                'file.py': {
-                    'percent_covered': 100.0,
-                    'violation_lines': [],
-                    'violations': []
-                }
-            },
-            'total_num_lines': 1,
-            'total_num_violations': 0,
-            'total_percent_covered': 100
-        })
+        expected = json.dumps(
+            {
+                "report_name": ["reports/coverage.xml"],
+                "diff_name": "master",
+                "src_stats": {
+                    "file.py": {
+                        "percent_covered": 100.0,
+                        "violation_lines": [],
+                        "violations": [],
+                    }
+                },
+                "total_num_lines": 1,
+                "total_num_violations": 0,
+                "total_percent_covered": 100,
+            }
+        )
 
         self.assert_report(expected)
 
@@ -339,14 +337,16 @@ class JsonReportGeneratorTest(BaseReportGeneratorTest):
         # Have the dependencies return an empty report
         # (this is the default)
 
-        expected = json.dumps({
-            'report_name': ['reports/coverage.xml'],
-            'diff_name': 'master',
-            'src_stats': {},
-            'total_num_lines': 0,
-            'total_num_violations': 0,
-            'total_percent_covered': 100
-        })
+        expected = json.dumps(
+            {
+                "report_name": ["reports/coverage.xml"],
+                "diff_name": "master",
+                "src_stats": {},
+                "total_num_lines": 0,
+                "total_num_violations": 0,
+                "total_percent_covered": 100,
+            }
+        )
 
         self.assert_report(expected)
 
@@ -361,7 +361,8 @@ class StringReportGeneratorTest(BaseReportGeneratorTest):
         self.use_default_values()
 
         # Verify that we got the expected string
-        expected = dedent("""
+        expected = dedent(
+            """
         -------------
         Diff Coverage
         Diff: master
@@ -373,19 +374,21 @@ class StringReportGeneratorTest(BaseReportGeneratorTest):
         Missing: 4 lines
         Coverage: 66%
         -------------
-        """).strip()
+        """
+        ).strip()
 
         self.assert_report(expected)
 
     def test_hundred_percent(self):
 
         # Have the dependencies return an empty report
-        self.set_src_paths_changed(['file.py'])
-        self.set_lines_changed('file.py', [line for line in range(0, 100)])
-        self.set_violations('file.py', [])
-        self.set_measured('file.py', [2])
+        self.set_src_paths_changed(["file.py"])
+        self.set_lines_changed("file.py", [line for line in range(0, 100)])
+        self.set_violations("file.py", [])
+        self.set_measured("file.py", [2])
 
-        expected = dedent("""
+        expected = dedent(
+            """
         -------------
         Diff Coverage
         Diff: master
@@ -396,7 +399,8 @@ class StringReportGeneratorTest(BaseReportGeneratorTest):
         Missing: 0 lines
         Coverage: 100%
         -------------
-        """).strip()
+        """
+        ).strip()
 
         self.assert_report(expected)
 
@@ -405,14 +409,16 @@ class StringReportGeneratorTest(BaseReportGeneratorTest):
         # Have the dependencies return an empty report
         # (this is the default)
 
-        expected = dedent("""
+        expected = dedent(
+            """
         -------------
         Diff Coverage
         Diff: master
         -------------
         No lines with coverage information in this diff.
         -------------
-        """).strip()
+        """
+        ).strip()
 
         self.assert_report(expected)
 
@@ -423,7 +429,7 @@ class HtmlReportGeneratorTest(BaseReportGeneratorTest):
 
     def test_generate_report(self):
         self.use_default_values()
-        expected = load_fixture('html_report.html')
+        expected = load_fixture("html_report.html")
         self.assert_report(expected)
 
     def test_empty_report(self):
@@ -432,7 +438,7 @@ class HtmlReportGeneratorTest(BaseReportGeneratorTest):
         # (this is the default)
 
         # Verify that we got the expected string
-        expected = load_fixture('html_report_empty.html')
+        expected = load_fixture("html_report_empty.html")
         self.assert_report(expected)
 
     def test_one_snippet(self):
@@ -444,7 +450,7 @@ class HtmlReportGeneratorTest(BaseReportGeneratorTest):
         self.set_num_snippets(1)
 
         # Verify that we got the expected string
-        expected = load_fixture('html_report_one_snippet.html').strip()
+        expected = load_fixture("html_report_one_snippet.html").strip()
         self.assert_report(expected)
 
     def test_multiple_snippets(self):
@@ -456,5 +462,5 @@ class HtmlReportGeneratorTest(BaseReportGeneratorTest):
         self.set_num_snippets(2)
 
         # Verify that we got the expected string
-        expected = load_fixture('html_report_two_snippets.html').strip()
+        expected = load_fixture("html_report_two_snippets.html").strip()
         self.assert_report(expected)
